==> ssp_api-1.0.0.4-sources.jar: com/cloud/hisavana/sdk/api/adx/ADefault.java <==
package com.cloud.hisavana.sdk.api.adx;

import com.cloud.hisavana.sdk.ad.base.AdxDefault;
import com.cloud.hisavana.sdk.data.bean.request.AdxImpBean;
import com.cloud.hisavana.sdk.data.bean.response.AdsDTO;
import com.cloud.hisavana.sdk.common.util.AdLogUtil;

import java.util.ArrayList;
import java.util.List;

public class ADefault {
    private List<AdxDefault> executors;
    public static StringBuffer stringBuffer = new StringBuffer();

    public void loadDefault(List<AdxImpBean> list){
        executors = new ArrayList<>();
        stringBuffer = new StringBuffer();
        for (AdxImpBean adxImpBean : list){
           executors.add(new AdxDefault(adxImpBean));
       }
        execute();
    }
//    public String getDefault(String pmid){
//        List<AdsDTO> list = AdxDefault.getDefaultAdItem(pmid,false);
//        StringBuffer result = new StringBuffer();
//        for (AdsDTO adsDTO : list){
//            result.append(adsDTO.toStringShort());
//        }
//        return result.toString();
//    }
    public void execute(){
        DefaultExecutor temp = null;
        DefaultExecutor head = null;
        for (AdxDefault impl : executors) {
            DefaultExecutor next = new DefaultExecutor(impl);
            if (temp == null) {
                head = next;
            } else {
                temp.nextExecutor(next);
            }
            temp = next;
        }
        if (head != null) {
            head.load();
        }
    }


    /**
     * 串行处理器
     */
    class DefaultExecutor {
        private DefaultExecutor nextExecutor;
        private AdxDefault aDefault;
        //在AdxDefault.load结束以后调用loadListerner.loadComplete()
        private AdxDefault.LoadListerner loadListerner = new AdxDefault.LoadListerner() {
            @Override
            public void loadComplete(boolean isSuccess) {
                AdLogUtil.ADX.d("AdxDefault - stop load default ad result - " + isSuccess);
                if (nextExecutor != null) {
                    nextExecutor.load();
                }
            }
        };
        public DefaultExecutor(AdxDefault adxDefault){
            this.aDefault = adxDefault;
            this.aDefault.setLoadListerner(loadListerner);
        }

        public void nextExecutor(DefaultExecutor executor) {
            this.nextExecutor = executor;
        }
        public void load() {
            if (aDefault != null) {
                //开始加载数据
                aDefault.loadAd();
            }
        }
        public void destroy() {
            if (aDefault != null) {
                aDefault.destroy();
                aDefault = null;
            }
            if (nextExecutor != null) {
                nextExecutor.destroy();
            }
        }
    }

}

==> ssp_api-1.0.0.11-sources.jar: com/cloud/hisavana/sdk/api/adx/ADefault.java <==
package com.cloud.hisavana.sdk.api.adx;

import com.cloud.hisavana.sdk.ad.base.AdxDefault;
import com.cloud.hisavana.sdk.common.util.AdLogUtil;
import com.cloud.hisavana.sdk.data.bean.request.AdxImpBean;

import java.util.ArrayList;
import java.util.List;

public class ADefault {
    private List<AdxDefault> executors;

    public void loadDefault(List<AdxImpBean> list){
        executors = new ArrayList<>();
        for (AdxImpBean adxImpBean : list){
           executors.add(new AdxDefault(adxImpBean));
       }
        execute();
    }
//    public String getDefault(String pmid){
//        List<AdsDTO> list = AdxDefault.getDefaultAdItem(pmid,false);
//        StringBuffer result = new StringBuffer();
//        for (AdsDTO adsDTO : list){
//            result.append(adsDTO.toStringShort());
//        }
//        return result.toString();
//    }
    public void execute(){
        DefaultExecutor temp = null;
        DefaultExecutor head = null;
        for (AdxDefault impl : executors) {
            DefaultExecutor next = new DefaultExecutor(impl);
            if (temp == null) {
                head = next;
            } else {
                temp.nextExecutor(next);
            }
            temp = next;
        }
        if (head != null) {
            head.load();
        }
    }


    /**
     * 串行处理器
     */
    class DefaultExecutor {
        private DefaultExecutor nextExecutor;
        private AdxDefault aDefault;
        //在AdxDefault.load结束以后调用loadListerner.loadComplete()
        private AdxDefault.LoadListerner loadListerner = new AdxDefault.LoadListerner() {
            @Override
            public void loadComplete(boolean isSuccess) {
                AdLogUtil.LOG.d("AdxDefault - stop load default ad result - " + isSuccess);
                if (nextExecutor != null) {
                    nextExecutor.load();
                }
            }
        };
        public DefaultExecutor(AdxDefault adxDefault){
            this.aDefault = adxDefault;
            this.aDefault.setLoadListerner(loadListerner);
        }

        public void nextExecutor(DefaultExecutor executor) {
            this.nextExecutor = executor;
        }
        public void load() {
            if (aDefault != null) {
                //开始加载数据
                aDefault.loadAd();
            }
        }
        public void destroy() {
            if (aDefault != null) {
                aDefault.destroy();
                aDefault = null;
            }
            if (nextExecutor != null) {
                nextExecutor.destroy();
            }
        }
    }

}
